// Bristleback plugin - Copyright (c) 2010 bristleback.googlecode.com
// ---------------------------------------------------------------------------
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software Foundation; either version 3 of the License, or (at your
// option) any later version.
// This library is distributed in the hope that it will be useful,
// but without any warranty; without even the implied warranty of merchantability
// or fitness for a particular purpose.
// You should have received a copy of the GNU Lesser General Public License along
// with this program; if not, see <http://www.gnu.org/licenses/lgpl.html>.
// ---------------------------------------------------------------------------
package pl.bristleback.server.bristle.config;

import org.apache.log4j.Logger;

/**
 * This is a convenient wrapper for classes taken from configuration file.
 * Class configuration contains name and type of the class. In most cases, classes can be created in two ways,
 * by creating new instance or by resolving Spring bean from context.
 * Useful functions related with class configuration can be found in {@link pl.bristleback.server.bristle.config.ClassConfigurationUtil}.
 * <p/>
 * Created on: 2010-10-14 20:04:47 <br/>
 *
 * @author Wojciech Niemiec
 */
public class ClassConfiguration {
  private static Logger log = Logger.getLogger(ClassConfiguration.class.getName());

  private String name;
  private String type;
  private boolean isSpringType;

  /**
   * Class configuration constructor, containing all necessary information.
   *
   * @param name       name of the class.
   * @param classType  type of the class.
   * @param springType true if type of the given class is a Spring bean reference name.
   */
  public ClassConfiguration(String name, String classType, boolean springType) {
    this.name = name;
    this.type = classType;
    isSpringType = springType;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public String getType() {
    return type;
  }

  public void setType(String type) {
    this.type = type;
  }

  public boolean isSpringType() {
    return isSpringType;
  }

  public void setSpringType(boolean springType) {
    isSpringType = springType;
  }
}
